pub struct ForwardedMegolmV2AesSha2Content {
pub room_id: OwnedRoomId,
pub session_id: String,
pub session_key: ExportedSessionKey,
pub claimed_sender_key: Curve25519PublicKey,
pub claimed_signing_keys: SigningKeys<DeviceKeyAlgorithm>,
/* private fields */
}Expand description
The m.megolm.v2.aes-sha2 variant of the m.forwarded_room_key content.
Fields
room_id: OwnedRoomIdThe room where the key is used.
session_id: StringThe ID of the session that the key is for.
session_key: ExportedSessionKeyThe key to be exchanged. Can be used to create a InboundGroupSession
that can be used to decrypt room events.
claimed_sender_key: Curve25519PublicKeyThe Curve25519 key of the device which initiated the session originally.
It is ‘claimed’ because the receiving device has no way to tell that the original room_key actually came from a device which owns the private part of this key.
claimed_signing_keys: SigningKeys<DeviceKeyAlgorithm>The Ed25519 key of the device which initiated the session originally.
It is ‘claimed’ because the receiving device has no way to tell that the original room_key actually came from a device which owns the private part of this key.